pub struct Cmp20DkgSession { /* private fields */ }Trait Implementations
Sourceimpl SessionImpl for Cmp20DkgSession
impl SessionImpl for Cmp20DkgSession
Sourcefn round(&mut self, incoming: &[Message]) -> Result<RoundResult>
fn round(&mut self, incoming: &[Message]) -> Result<RoundResult>
Advance one round. Consumes the messages received since the last
round and returns the messages to send next, plus a
complete
flag indicating the session has produced its output and no more
rounds are needed.Auto Trait Implementations
impl Freeze for Cmp20DkgSession
impl RefUnwindSafe for Cmp20DkgSession
impl Send for Cmp20DkgSession
impl Sync for Cmp20DkgSession
impl Unpin for Cmp20DkgSession
impl UnsafeUnpin for Cmp20DkgSession
impl UnwindSafe for Cmp20DkgSession